package com.ptc.activetime;

import javax.websocket.CloseReason;
import javax.websocket.OnClose;
import javax.websocket.OnMessage;
import javax.websocket.OnOpen;
import javax.websocket.RemoteEndpoint;
import javax.websocket.Session;
import javax.websocket.server.ServerEndpoint;

@ServerEndpoint("/wsTestActiveTime")
public class WsServer {

	private static int activeSessionCount = 0;

	@OnOpen
	public void OnOpen(Session session) {
		String sessionId = session.getId();
		System.out.println("A websocket connection got opened with id " + sessionId);
		session.setMaxIdleTimeout(10000);
		activeSessionCount++;
		new Thread(new ContinuousMessageSender(session)).start();
	}

	public static int getActiveSessionsCount() {
		return activeSessionCount;
	}

	@OnClose
	public void OnClose(CloseReason reason) {
		activeSessionCount--;
		System.out.println("A websocket connection got closed due to reason " + reason.getReasonPhrase());
	}

	@OnMessage
	public void onMeessage(String message) {
		System.out.println("Received the message " + message);
	}

	private class ContinuousMessageSender implements Runnable {
		RemoteEndpoint.Basic endPoint;
		Session session;
		private int counter = 0;
		private boolean flag = true;

		public ContinuousMessageSender(Session session) {
			this.session = session;
			this.endPoint = session.getBasicRemote();
		}

		@Override
		public void run() {
			while (flag) {
				try {
					if (session.isOpen()) {
						endPoint.sendText("Sending New Message: " + counter++);
					} else {
						flag = false;
					}
					Thread.sleep(2000);
				} catch (Exception e) {
					e.printStackTrace();
				}
			}

		}

	}
}
